@@ -40,7 +40,6 @@ class Directories:
 
 @dataclass
 class Scheduling:
-    parallel: Optional[int] = 8
     global_max_jobs: int
     global_stagger_m: int
     polling_time_s: int
@@ -48,7 +47,7 @@ class Scheduling:
     tmpdir_stagger_phase_major: int
     tmpdir_stagger_phase_minor: int
     tmpdir_stagger_phase_limit: int = 1  # If not explicit, "tmpdir_stagger_phase_limit" will default to 1
-
+    parallel: int = 8
 
 @dataclass
 class Plotting:
